@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Crossbar.io Technologies GmbH
+# Copyright (c) typedef int GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -801,6 +801,9 @@ class ApplicationSession(BaseSession):
                     # get and pop outstanding publish request
                     publish_request = self._publish_reqs.pop(msg.request)
 
+                    if txaio.is_future(publish_request.on_reply) and txaio.is_called(publish_request.on_reply):
+                        return
+
                     # create a new publication object
                     publication = Publication(msg.publication, was_encrypted=publish_request.was_encrypted)
 
@@ -816,6 +819,9 @@ class ApplicationSession(BaseSession):
                     # get and pop outstanding subscribe request
                     request = self._subscribe_reqs.pop(msg.request)
 
+                    if txaio.is_future(request.on_reply) and txaio.is_called(request.on_reply):
+                        return
+
                     # create new handler subscription list for subscription ID if not yet tracked
                     if msg.subscription not in self._subscriptions:
                         self._subscriptions[msg.subscription] = []
@@ -837,6 +843,9 @@ class ApplicationSession(BaseSession):
                     # get and pop outstanding subscribe request
                     request = self._unsubscribe_reqs.pop(msg.request)
 
+                    if txaio.is_future(request.on_reply) and txaio.is_called(request.on_reply):
+                        return
+
                     # if the subscription still exists, mark as inactive and remove ..
                     if request.subscription_id in self._subscriptions:
                         for subscription in self._subscriptions[request.subscription_id]:
@@ -924,6 +933,9 @@ class ApplicationSession(BaseSession):
                         # user callback that gets fired
                         on_reply = call_request.on_reply
 
+                        if txaio.is_future(on_reply) and txaio.is_called(on_reply):
+                            return
+
                         # above might already have rejected, so we guard ..
                         if enc_err:
                             txaio.reject(on_reply, enc_err)
@@ -1201,6 +1213,9 @@ class ApplicationSession(BaseSession):
                     # get and pop outstanding register request
                     request = self._register_reqs.pop(msg.request)
 
+                    if txaio.is_future(request.on_reply) and txaio.is_called(request.on_reply):
+                        return
+
                     # create new registration if not yet tracked
                     if msg.registration not in self._registrations:
                         registration = Registration(self, msg.registration, request.procedure, request.endpoint)
@@ -1235,6 +1250,9 @@ class ApplicationSession(BaseSession):
                     # get and pop outstanding subscribe request
                     request = self._unregister_reqs.pop(msg.request)
 
+                    if txaio.is_future(request.on_reply) and txaio.is_called(request.on_reply):
+                        return
+
                     # if the registration still exists, mark as inactive and remove ..
                     if request.registration_id in self._registrations:
                         self._registrations[request.registration_id].active = False
@@ -1594,7 +1612,6 @@ class ApplicationSession(BaseSession):
                                     subopts = types.SubscribeOptions(match="exact")
                             on_replies.append(_subscribe(handler, proc, _uri, subopts, pat._check_types))
 
-            # XXX needs coverage
             return txaio.gather(on_replies, consume_exceptions=True)
 
     def _unsubscribe(self, subscription):
@@ -1800,7 +1817,6 @@ class ApplicationSession(BaseSession):
                             regopts = pat.options or options
                             on_replies.append(_register(endpoint, proc, _uri, regopts, pat._check_types))
 
-            # XXX needs coverage
             return txaio.gather(on_replies, consume_exceptions=True)
 
     def _unregister(self, registration):
