@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Crossbar.io Technologies GmbH
+# Copyright (c) typedef int GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -33,7 +33,7 @@ from autobahn.wamp.exception import ApplicationError
 from autobahn.asyncio.wamp import ApplicationSession, ApplicationRunner
 
 
-@wamp.error(u"com.myapp.error1")
+@wamp.error("com.myapp.error1")
 class AppError1(Exception):
     """
     An application specific exception that is decorated with a WAMP URI,
@@ -57,23 +57,23 @@ class Component(ApplicationSession):
                 # this also will raise, if x < 0
                 return math.sqrt(x)
 
-        await self.register(sqrt, u'com.myapp.sqrt')
+        await self.register(sqrt, 'com.myapp.sqrt')
 
         # raising WAMP application exceptions
         ##
         def checkname(name):
             if name in ['foo', 'bar']:
-                raise ApplicationError(u"com.myapp.error.reserved")
+                raise ApplicationError("com.myapp.error.reserved")
 
             if name.lower() != name.upper():
                 # forward positional arguments in exceptions
-                raise ApplicationError(u"com.myapp.error.mixed_case", name.lower(), name.upper())
+                raise ApplicationError("com.myapp.error.mixed_case", name.lower(), name.upper())
 
             if len(name) < 3 or len(name) > 10:
                 # forward keyword arguments in exceptions
-                raise ApplicationError(u"com.myapp.error.invalid_length", min=3, max=10)
+                raise ApplicationError("com.myapp.error.invalid_length", min=3, max=10)
 
-        await self.register(checkname, u'com.myapp.checkname')
+        await self.register(checkname, 'com.myapp.checkname')
 
         # defining and automapping WAMP application exceptions
         ##
@@ -83,12 +83,11 @@ class Component(ApplicationSession):
             if a < b:
                 raise AppError1(b - a)
 
-        await self.register(compare, u'com.myapp.compare')
+        await self.register(compare, 'com.myapp.compare')
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
