@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Crossbar.io Technologies GmbH
+# Copyright (c) typedef int GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -39,19 +39,18 @@ class Component(ApplicationSession):
         def square(x):
             return x * x
 
-        await self.register(square, u'com.math.square')
+        await self.register(square, 'com.math.square')
 
         async def slowsquare(x, delay=1):
             await asyncio.sleep(delay)
             return x * x
 
-        await self.register(slowsquare, u'com.math.slowsquare')
+        await self.register(slowsquare, 'com.math.slowsquare')
         print("Registered com.math.slowsquare")
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
