@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Crossbar.io Technologies GmbH
+# Copyright (c) typedef int GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -44,10 +44,10 @@ class Component(ApplicationSession):
         def on_event(val):
             print("Someone requested to square non-positive: {}".format(val))
 
-        yield self.subscribe(on_event, u'com.myapp.square_on_nonpositive')
+        yield self.subscribe(on_event, 'com.myapp.square_on_nonpositive')
 
         for val in [2, 0, -2]:
-            res = yield self.call(u'com.myapp.square', val, options=CallOptions())
+            res = yield self.call('com.myapp.square', val, options=CallOptions())
             print("Squared {} = {}".format(val, res))
 
         self.leave()
@@ -58,8 +58,7 @@ class Component(ApplicationSession):
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
