@@ -4,13 +4,13 @@ from autobahn.wamp import Api
 # register/subscribe WAMP actions
 api = Api()
 
-@api.register(u'com.example.add2')
+@api.register('com.example.add2')
 def add2(a, b):
     return a + b
 
-@api.subscribe(u'com.example.on-hello', details=True)
+@api.subscribe('com.example.on-hello', details=True)
 def on_hello(msg, details=None):
-    print(u'Someone said: {}'.format(msg))
+    print('Someone said: {}'.format(msg))
     details.session.leave()
 
 @coroutine
@@ -29,8 +29,8 @@ def component2(reactor, session):
     A second component, which gets called "main-like".
     When it returns, this will automatically close the session.
     """
-    result = yield session.call(u'com.example.add2', 2, 3)
-    session.publish(u'com.example.on-hello', u'result={}'.format(result))
+    result = yield session.call('com.example.add2', 2, 3)
+    session.publish('com.example.on-hello', 'result={}'.format(result))
 
 
 if __name__ == '__main__':
